package menuPackage;

import java.awt.Color;
import java.awt.Font;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import java.io.IOException;
import java.sql.SQLException;
import java.util.LinkedList;

import javax.imageio.ImageIO;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JPanel;


/**
 * This class is a JPanel which is used for the main menu of the GUI. It has options to add, edit, remove
 * menu items. All panels store textfields and buttons for the user.
 * 
 * @author Pradnya
 *
 */
public class MainMenuPanel extends JPanel{
	private JButton Add,Edit,Remove, Ingredients;
	private JFrame frame;
	LinkedList<MenuItem> menu;
	
	public MainMenuPanel(JFrame frame,LinkedList<MenuItem> menu){
		
		this.frame=frame;
		this.menu=menu;
		
		//Creates the actual Buttons
		Add = new JButton("Add Menu Item");
		/*Add.setFont(new Font("Arial Bold", Font.PLAIN, 12));
        Add.setForeground(new Color(0xFBB917));
        Add.setBackground(new Color(0x000000));
        */
		
		//Edit = new JButton("Print Menu");
		Edit = new JButton("Edit Menu Item");
		Remove = new JButton("Remove Menu Item");
		
		Ingredients = new JButton("Ingredients Menu Item");
		
		/* Every textfield/button/etc needs an action listener. The action listener
		 * waits for the user to click or do something in the GUI and proceeds to perform
		 * a different task. ButtonListener is a private class created below
		 */
		
		Add.addActionListener(new ButtonListener(this));
		Edit.addActionListener(new ButtonListener(this));
		Remove.addActionListener(new ButtonListener(this));
		
		//Adds the buttons to the Panel itself.
		add(Add);
		add(Edit);
		add(Remove);
	}
	
	
	/**
	 * This class waits for a user to click a button. All ActionListeners
	 * must have a method called actionPerformed. This is what the program will do
	 * when a button or something is pushed. 
	 *
	 */
	
	public class ButtonListener implements ActionListener{
		MainMenuPanel m;
		
		public ButtonListener(MainMenuPanel m){
			this.m = m;
		}
		/**
		 * the method checks to see which button was selected. That is what the 
		 * three different if statements do. ActionEvent is a class describing
		 * literally an event. this method checks the source of the event and
		 * depending on which button was pressed will do different things.
		 */
		public void actionPerformed (ActionEvent event){
			if (event.getSource()==Add){
				//Removes the main menu screen from the window
				frame.getContentPane().remove(m);
				
				//Sets the window to now show the AddMenuItem Interface
				frame.getContentPane().add(new AddPanel(frame,menu));
				
				//Always required
				frame.setSize(600, 250);
				//frame.pack();
				frame.setVisible(true);
			}
			
			else if(event.getSource()==Edit){
				MenuItem cur;
				
				//Prints each items information to the console
				for(int i=0;i<menu.size();i++){
					cur=menu.get(i);
					cur.printItem();
				}
				
				//Removes the main menu screen from the window
				frame.getContentPane().remove(m);
					
				//Sets the window to now show the ViewMenu Interface
				//Read the ViewMenuPanel code before reading the EditMenuItemPanel code
			//	frame.getContentPane().add(new ViewMenuPanel(frame,menu));
			
				try {
					frame.getContentPane().add(new EditMenuFoodItemPanel(frame,menu));
				} catch (SQLException e) {
					// TODO Auto-generated catch block
					e.printStackTrace();
				}
				
				//Always Required
			
				frame.setSize(600, 300);
				//frame.pack();
				frame.setVisible(true);
				
			}
			else if(event.getSource()==Remove){
				frame.getContentPane().remove(m);
				
				//Sets the window to now show the RemoveMenuItem Interface
					try {
						frame.getContentPane().add(new RemoveMenuItemPanel(frame,menu));
					} catch (SQLException e) {
						// TODO Auto-generated catch block
						e.printStackTrace();
					}
				
				//Always required
				
					frame.setSize(600,250);
				//frame.pack();
				frame.setVisible(true);
				
		/*		String itemName = "Food Item";
				int result = 0;
				clsDataAccess myDataAccess = new clsDataAccess();
				//myDataAccess.removeMenuItems("test432");
				result = myDataAccess.removeMenuItems(itemName);
				
				if (result > 0){
				System.out.println(itemName +" Item Successfully Removed");
				//System.out.println("Item Successfully Removed");
				System.out.println("Remove"); */
				}
			}
		}
	}
	
